############
N1QL Queries
############

.. currentmodule:: couchbase.cluster

.. class:: QueryOptions

    .. automethod:: __init__

.. class:: QueryScanConsistency
    .. autodata:: NOT_BOUNDED
    .. autodata:: REQUEST_PLUS

.. currentmodule:: couchbase.mutation_state
.. autoclass:: MutationState

.. currentmodule:: couchbase.n1ql
.. class:: QueryResult

    .. automethod:: __init__

.. class:: QueryMetrics

    .. automethod:: __init__

.. class:: QueryWarning

    .. automethod:: __init__

.. class:: QueryStatus

    .. automethod:: __init__

.. class:: QueryMetaData

    .. automethod:: __init__
